@@ -424,25 +424,7 @@ impl<'a> SuperFieldAccessFolder<'a> {
                 BinExpr {
                     span: DUMMY_SP,
                     left,
-                    op: match op {
-                        op!("=") => unreachable!(),
-
-                        op!("+=") => op!(bin, "+"),
-                        op!("-=") => op!(bin, "-"),
-                        op!("*=") => op!("*"),
-                        op!("/=") => op!("/"),
-                        op!("%=") => op!("%"),
-                        op!("<<=") => op!("<<"),
-                        op!(">>=") => op!(">>"),
-                        op!(">>>=") => op!(">>>"),
-                        op!("|=") => op!("|"),
-                        op!("&=") => op!("&"),
-                        op!("^=") => op!("^"),
-                        op!("**=") => op!("**"),
-                        op!("&&=") => op!("&&"),
-                        op!("||=") => op!("||"),
-                        op!("??=") => op!("??"),
-                    },
+                    op: op.to_update().unwrap(),
                     right: rhs,
                 }
                 .as_arg()
